*--------------------------------------------------------------------------
* Model generated by Motega software: 
*
*              Modeling Of Tubes Employing Genetic Algorithms
*
* Models contain 1G resistors from all nodes to earth in order to avoid
* floating nodes. Triode and tetrode/pentode models contain a diode for
* simulating grid current.
*
* Non-commercial use is permitted, but at your own risk... This model
* is provided "as is", without warranty of any kind. In no event shall
* Jeroen Boschma be liable for any claim, damages or other liability,
* whether in an action of contract, tort or otherwise, arising from,
* out of or in connection with the tube model or the use or other
* dealings in the tube model.
*
*
*                         Copyright Jeroen Boschma
*                              www.boschma.com
*
* Motega V 1.1, 26-Feb-2011 22:23:56
*--------------------------------------------------------------------------



*--------------------------------------------------------------------------
* Generic tetrode/pentode model
*--------------------------------------------------------------------------

.SUBCKT TubePentode  A  Gr2  Gr1  K
+ PARAMS: ua=1 ug2=1 xa=1 xg2=1 qa=1 qg2=1 kg1=1 kg2=1 kvba=1 kvbg2=1 ce=1
*
* Resistors in order to avoid floating nodes
*
R1   A    0   1G
R2   Gr2  0   1G
R3   Gr1  0   1G
R4   K    0   1G
*
* Intermediate expressions which simplify the current calculation
*
RE1  1    0   1G
E1   1    0   VALUE={xa + ce*PWR(V(Gr2,K),2)}
RE2  2    0   1G
E2   2    0   VALUE={V(Gr2,K)*LOG(1 + EXP(qa*(1/ua + V(Gr1,K)/V(Gr2,K))))/qa}
RE3  3    0   1G
E3   3    0   VALUE={V(Gr2,K)*LOG(1 + EXP(qg2*(1/ug2 + V(Gr1,K)/V(Gr2,K))))/qg2}
*
* Actual current calculation
*
G1   A    K   VALUE={(PWR(V(2),V(1)) + PWRS(V(2),V(1)))*ATAN(V(A,K)/kvba)/kg1}
G2   Gr2  K   VALUE={(PWR(V(3),xg2) + PWRS(V(3),xg2))*ATAN(V(A,K)/kvbg2)/kg2}
*
* Grid current modeling
*
RG   Gr1  4   1K
D1   4    K   DX
.MODEL DX D(IS=1N RS=1 CJO=10PF TT=1N)
*
* Close the model
*
.ENDS


*--------------------------------------------------------------------------
* Specialized tube model
*
*    Type           : 6Z43P
*    Description    : Pentode High S
*    Direct heated  : no
*    Screen present : yes
*--------------------------------------------------------------------------

.SUBCKT 6Z43P    A  Gr2  Gr1  K 
*
* Resistors in order to avoid floating nodes
*
* RF   F    0   1G
* RS   S    0   1G
*
* Link to the generic model
*
XV1     A         Gr2      Gr1      K       TubePentode
+ PARAMS: ua=76.129 ug2=8.581K xa=759.154M xg2=952.570M qa=233.302 qg2=151.489
+ kg1=68.216 kg2=142.261 kvba=19.057 kvbg2=2.179M ce=22.808U
*
* Capacitances
*
C1    K        A        3.300P   ; Cka
C2    Gr1      K        13.500P   ; Cgk
* C3    Gr1      F        0.150P   ; Cgh
C4    Gr1      A        0.075P   ; Cga
*
* Close the model
*
.ENDS


*--------------------------------------------------------------------------
* End of file
*--------------------------------------------------------------------------
